pub struct Matcher(/* private fields */);Expand description
Filter for file paths that uses zero or more glob patterns to perform matching.
Implementations
Sourceimpl Matcher
impl Matcher
Sourcepub fn build<'a, I, S>(pattern_strs: I) -> Result<Self, Error>
pub fn build<'a, I, S>(pattern_strs: I) -> Result<Self, Error>
Attempts to build a matcher out of an iterable of string-likes.